Struct WpImageDescriptionV1

pub struct WpImageDescriptionV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
Colorimetric image description

An image description carries information about the pixel color encoding and its intended display and viewing environment. The image description is attached to a wl_surface via wp_color_management_surface_v1.set_image_description. A compositor can use this information to decode pixel values into colorimetrically meaningful quantities, which allows the compositor to transform the surface contents to become suitable for various displays and viewing environments.

Note, that the wp_image_description_v1 object is not ready to be used immediately after creation. The object eventually delivers either the ‘ready’ or the ‘failed’ event, specified in all requests creating it. The object is deemed “ready” after receiving the ‘ready’ event.

An object which is not ready is illegal to use, it can only be destroyed. Any other request in this interface shall result in the ‘not_ready’ protocol error. Attempts to use an object which is not ready through other interfaces shall raise protocol errors defined there.

Once created and regardless of how it was created, a wp_image_description_v1 object always refers to one fixed image description. It cannot change after creation.

See also the Event enum for this interface.

Implementations



impl WpImageDescriptionV1

pub fn destroy(&self)

destroy the image description

Destroy this object. It is safe to destroy an object which is not ready.

Destroying a wp_image_description_v1 object has no side-effects, not even if a wp_color_management_surface_v1.set_image_description has not yet been followed by a wl_surface.commit.

pub fn get_information<U, D>( &self, qh: &QueueHandle<D>, udata: U, ) -> WpImageDescriptionInfoV1
where U: Send + Sync + 'static, D: Dispatch<WpImageDescriptionInfoV1, U> + 'static,

get information about the image description

Creates a wp_image_description_info_v1 object which delivers the information that makes up the image description.

Not all image description protocol objects allow get_information request. Whether it is allowed or not is defined by the request that created the object. If get_information is not allowed, the protocol error no_information is raised.